Class: Aws::MediaStoreData::Types::GetObjectRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaStoreData::Types::GetObjectRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediastoredata/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#path ⇒ String
The path (including the file name) where the object is stored in the container.
-
#range ⇒ String
The range bytes of an object to retrieve.
Instance Attribute Details
#path ⇒ String
The path (including the file name) where the object is stored in the container. Format: <folder name>/<folder name>/<file name>
For example, to upload the file mlaw.avi to the folder path
premium\canada in the container movies, enter the path
premium/canada/mlaw.avi.
Do not include the container name in this path.
If the path includes any folders that don't exist yet, the service
creates them. For example, suppose you have an existing
premium/usa subfolder. If you specify premium/canada, the
service creates a canada subfolder in the premium folder. You
then have two subfolders, usa and canada, in the premium
folder.
There is no correlation between the path to the source and the path (folders) in the container in AWS Elemental MediaStore.
For more information about folders and how they exist in a container, see the AWS Elemental MediaStore User Guide.
The file name is the name that is assigned to the file that you upload. The file can have the same name inside and outside of AWS Elemental MediaStore, or it can have the same name. The file name can include or omit an extension.
147 148 149 150 151 152 |
# File 'lib/aws-sdk-mediastoredata/types.rb', line 147 class GetObjectRequest < Struct.new( :path, :range) SENSITIVE = [] include Aws::Structure end |
#range ⇒ String
The range bytes of an object to retrieve. For more information about
the Range header, see
http://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.35.
AWS Elemental MediaStore ignores this header for partially uploaded
objects that have streaming upload availability.
147 148 149 150 151 152 |
# File 'lib/aws-sdk-mediastoredata/types.rb', line 147 class GetObjectRequest < Struct.new( :path, :range) SENSITIVE = [] include Aws::Structure end |