Class: Aws::MediaStoreData::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::MediaStoreData::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-mediastoredata/client.rb
Overview
An API client for MediaStoreData. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::MediaStoreData::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#delete_object(params = {}) ⇒ Struct
Deletes an object at the specified path.
-
#describe_object(params = {}) ⇒ Types::DescribeObjectResponse
Gets the headers for an object at the specified path.
-
#get_object(params = {}) ⇒ Types::GetObjectResponse
Downloads the object at the specified path.
-
#list_items(params = {}) ⇒ Types::ListItemsResponse
Provides a list of metadata entries about folders and objects in the specified folder.
-
#put_object(params = {}) ⇒ Types::PutObjectResponse
Uploads an object to the specified path.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-mediastoredata/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
820 821 822 |
# File 'lib/aws-sdk-mediastoredata/client.rb', line 820 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
823 824 825 |
# File 'lib/aws-sdk-mediastoredata/client.rb', line 823 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 |
# File 'lib/aws-sdk-mediastoredata/client.rb', line 793 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::MediaStoreData') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-mediastoredata' context[:gem_version] = '1.84.0' Seahorse::Client::Request.new(handlers, context) end |
#delete_object(params = {}) ⇒ Struct
Deletes an object at the specified path.
496 497 498 499 |
# File 'lib/aws-sdk-mediastoredata/client.rb', line 496 def delete_object(params = {}, = {}) req = build_request(:delete_object, params) req.send_request() end |
#describe_object(params = {}) ⇒ Types::DescribeObjectResponse
Gets the headers for an object at the specified path.
534 535 536 537 |
# File 'lib/aws-sdk-mediastoredata/client.rb', line 534 def describe_object(params = {}, = {}) req = build_request(:describe_object, params) req.send_request() end |
#get_object(params = {}) ⇒ Types::GetObjectResponse
Downloads the object at the specified path. If the object’s upload availability is set to ‘streaming`, AWS Elemental MediaStore downloads the object even if it’s still uploading the object.
619 620 621 622 |
# File 'lib/aws-sdk-mediastoredata/client.rb', line 619 def get_object(params = {}, = {}, &block) req = build_request(:get_object, params) req.send_request(, &block) end |
#list_items(params = {}) ⇒ Types::ListItemsResponse
Provides a list of metadata entries about folders and objects in the specified folder.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
682 683 684 685 |
# File 'lib/aws-sdk-mediastoredata/client.rb', line 682 def list_items(params = {}, = {}) req = build_request(:list_items, params) req.send_request() end |
#put_object(params = {}) ⇒ Types::PutObjectResponse
Uploads an object to the specified path. Object sizes are limited to 25 MB for standard upload availability and 10 MB for streaming upload availability.
784 785 786 787 |
# File 'lib/aws-sdk-mediastoredata/client.rb', line 784 def put_object(params = {}, = {}) req = build_request(:put_object, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
813 814 815 |
# File 'lib/aws-sdk-mediastoredata/client.rb', line 813 def waiter_names [] end |